@@ -30,7 +30,11 @@ class Abstract_ADBDGL_Adapter(ABC):
         raise NotImplementedError  # pragma: no cover
 
     def dgl_to_arangodb(
-        self, name: str, dgl_g: Union[DGLGraph, DGLHeteroGraph], batch_size: int
+        self,
+        name: str,
+        dgl_g: Union[DGLGraph, DGLHeteroGraph],
+        overwrite_graph: bool = False,
+        **import_options: Any,
     ) -> ArangoDBGraph:
         raise NotImplementedError  # pragma: no cover
 
@@ -48,23 +52,13 @@ class Abstract_ADBDGL_Adapter(ABC):
     def __prepare_adb_attributes(self) -> None:
         raise NotImplementedError  # pragma: no cover
 
-    def __insert_adb_docs(self) -> None:
-        raise NotImplementedError  # pragma: no cover
-
     def __fetch_adb_docs(self) -> None:
         raise NotImplementedError  # pragma: no cover
 
-    def __validate_attributes(self) -> None:
-        raise NotImplementedError  # pragma: no cover
-
     @property
     def DEFAULT_CANONICAL_ETYPE(self) -> List[DGLCanonicalEType]:
         return [("_N", "_E", "_N")]
 
-    @property
-    def METAGRAPH_ATRIBS(self) -> Set[str]:
-        return {"vertexCollections", "edgeCollections"}
-
 
 class Abstract_ADBDGL_Controller(ABC):
     def _adb_attribute_to_dgl_feature(self, key: str, col: str, val: Any) -> Any:
